import { cn } from "@/lib/utils";
import { Loader2 } from "lucide-react";
import { useTranslations } from "next-intl";


interface FormButtonsProps {
	onPrevious: () => void;
	onNext: () => void;
	previousText?: string;
	nextText?: string;
	isPending?: boolean;
	classname?: string;
}

const FormButtons = ({
	onPrevious,
	onNext,
	previousText = "Previous",
	nextText = "Next",
	isPending = false,
	classname

}: FormButtonsProps) => {
	const t = useTranslations();

	return (
		<div className={cn("absolute right-0 bottom-0 z-50 p-4 flex gap-5", classname)}>
			<button
				type="button"
				onClick={onNext}
				className="w-32 h-12 text-lg text-center text-white py-2 bg-gradient-to-r from-[#1E1E1E] to-[rgba(30,30,30,0.7)] rounded-full transition-transform duration-300 ease-in-out hover:scale-105 hover:shadow-xl focus:outline-none focus:ring-4 focus:ring-gray-600"
				style={{ boxShadow: "#0000008f 0 5px 5px" }}
				disabled={isPending}
			>
				{isPending ? <Loader2 className="animate-spin mx-auto" /> : t(nextText)}
			</button>
			<button
				type="button"
				onClick={onPrevious}
				className="w-32 h-12 text-lg text-center text-white py-2 bg-gradient-to-r from-[#1E1E1E] to-[rgba(30,30,30,0.7)] rounded-full transition-transform duration-300 ease-in-out hover:scale-105 hover:shadow-xl focus:outline-none focus:ring-4 focus:ring-gray-600"
				style={{ boxShadow: "#0000008f 0 5px 5px" }}
			>
				{t(previousText)}
			</button>
		</div>
	);
};

export default FormButtons;
